

class DeploymentData(object):
    swagger_types = {
        'name': 'str',
        'config': 'DeploymentConfig',
        'runtime': 'str',
        'framework': 'str'
    }

    attribute_map = {
        'name': 'name',
        'config': 'config',
        'runtime': 'runtime',
        'framework': 'framework'
    }

    def __init__(self, name=None, config=None, runtime=None, framework=None):
        """
        ProjectData - a model defined in Swagger
        """

        self._name = None
        self._config = None
        self._runtime = None
        self._framework = None

        self.name = name

        if config is not None:
            self.config = config

        if runtime is not None:
            self.runtime = runtime

        if framework is not None:
            self.framework = framework

    @property
    def name(self):
        """
        Gets the name of this ServerData.
        Server name.

        :return: The name of this ServerData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServerData.
        Server name.

        :param name: The name of this ServerData.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def config(self):
        """
        Gets the name of this ServerData.
        Server name.

        :return: The name of this ServerData.
        :rtype: str
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the name of this ServerData.
        Server name.

        :param name: The name of this ServerData.
        :type: str
        """
        if config is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._config = config

    @property
    def runtime(self):
        """
        Gets the name of this ServerData.
        Server name.

        :return: The name of this ServerData.
        :rtype: str
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """
        Sets the name of this ServerData.
        Server name.

        :param name: The name of this ServerData.
        :type: str
        """
        if runtime is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._runtime = runtime

    @property
    def framework(self):
        """
        Gets the name of this ServerData.
        Server name.

        :return: The name of this ServerData.
        :rtype: str
        """
        return self._framework

    @framework.setter
    def framework(self, framework):
        """
        Sets the name of this ServerData.
        Server name.

        :param name: The name of this ServerData.
        :type: str
        """
        if framework is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._framework = framework


# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class UserProfileError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'bio': 'list[str]',
        'url': 'list[str]',
        'location': 'list[str]',
        'company': 'list[str]',
        'timezone': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'bio': 'bio',
        'url': 'url',
        'location': 'location',
        'company': 'company',
        'timezone': 'timezone'
    }

    def __init__(self, non_field_errors=None, bio=None, url=None, location=None, company=None, timezone=None):
        """
        UserProfileError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._bio = None
        self._url = None
        self._location = None
        self._company = None
        self._timezone = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if bio is not None:
          self.bio = bio
        if url is not None:
          self.url = url
        if location is not None:
          self.location = location
        if company is not None:
          self.company = company
        if timezone is not None:
          self.timezone = timezone

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this UserProfileError.
        Errors not connected to any field.

        :return: The non_field_errors of this UserProfileError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this UserProfileError.
        Errors not connected to any field.

        :param non_field_errors: The non_field_errors of this UserProfileError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def bio(self):
        """
        Gets the bio of this UserProfileError.
        Bio field errors.

        :return: The bio of this UserProfileError.
        :rtype: list[str]
        """
        return self._bio

    @bio.setter
    def bio(self, bio):
        """
        Sets the bio of this UserProfileError.
        Bio field errors.

        :param bio: The bio of this UserProfileError.
        :type: list[str]
        """

        self._bio = bio

    @property
    def url(self):
        """
        Gets the url of this UserProfileError.
        URL field errors.

        :return: The url of this UserProfileError.
        :rtype: list[str]
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this UserProfileError.
        URL field errors.

        :param url: The url of this UserProfileError.
        :type: list[str]
        """

        self._url = url

    @property
    def location(self):
        """
        Gets the location of this UserProfileError.
        Location field errors.

        :return: The location of this UserProfileError.
        :rtype: list[str]
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this UserProfileError.
        Location field errors.

        :param location: The location of this UserProfileError.
        :type: list[str]
        """

        self._location = location

    @property
    def company(self):
        """
        Gets the company of this UserProfileError.
        Company field errors.

        :return: The company of this UserProfileError.
        :rtype: list[str]
        """
        return self._company

    @company.setter
    def company(self, company):
        """
        Sets the company of this UserProfileError.
        Company field errors.

        :param company: The company of this UserProfileError.
        :type: list[str]
        """

        self._company = company

    @property
    def timezone(self):
        """
        Gets the timezone of this UserProfileError.
        Timezone field errors.

        :return: The timezone of this UserProfileError.
        :rtype: list[str]
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this UserProfileError.
        Timezone field errors.

        :param timezone: The timezone of this UserProfileError.
        :type: list[str]
        """

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UserProfileError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class CollaboratorError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'id': 'list[str]',
        'owner': 'list[str]',
        'joined': 'list[str]',
        'username': 'list[str]',
        'email': 'list[str]',
        'first_name': 'list[str]',
        'last_name': 'list[str]',
        'member': 'list[str]',
        'permissions': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'id': 'id',
        'owner': 'owner',
        'joined': 'joined',
        'username': 'username',
        'email': 'email',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'member': 'member',
        'permissions': 'permissions'
    }

    def __init__(self, non_field_errors=None, id=None, owner=None, joined=None, username=None, email=None, first_name=None, last_name=None, member=None, permissions=None):
        """
        CollaboratorError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._id = None
        self._owner = None
        self._joined = None
        self._username = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._member = None
        self._permissions = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if id is not None:
          self.id = id
        if owner is not None:
          self.owner = owner
        if joined is not None:
          self.joined = joined
        if username is not None:
          self.username = username
        if email is not None:
          self.email = email
        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name
        self.member = member
        self.permissions = permissions

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this CollaboratorError.
        Errors not connected to any field.

        :return: The non_field_errors of this CollaboratorError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this CollaboratorError.
        Errors not connected to any field.

        :param non_field_errors: The non_field_errors of this CollaboratorError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def id(self):
        """
        Gets the id of this CollaboratorError.
        Id field errors this

        :return: The id of this CollaboratorError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CollaboratorError.
        Id field errors this

        :param id: The id of this CollaboratorError.
        :type: list[str]
        """

        self._id = id

    @property
    def owner(self):
        """
        Gets the owner of this CollaboratorError.
        Owner field errors.

        :return: The owner of this CollaboratorError.
        :rtype: list[str]
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this CollaboratorError.
        Owner field errors.

        :param owner: The owner of this CollaboratorError.
        :type: list[str]
        """

        self._owner = owner

    @property
    def joined(self):
        """
        Gets the joined of this CollaboratorError.
        Joined field errors.

        :return: The joined of this CollaboratorError.
        :rtype: list[str]
        """
        return self._joined

    @joined.setter
    def joined(self, joined):
        """
        Sets the joined of this CollaboratorError.
        Joined field errors.

        :param joined: The joined of this CollaboratorError.
        :type: list[str]
        """

        self._joined = joined

    @property
    def username(self):
        """
        Gets the username of this CollaboratorError.
        Username field errors.

        :return: The username of this CollaboratorError.
        :rtype: list[str]
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this CollaboratorError.
        Username field errors.

        :param username: The username of this CollaboratorError.
        :type: list[str]
        """

        self._username = username

    @property
    def email(self):
        """
        Gets the email of this CollaboratorError.
        Email field errors.

        :return: The email of this CollaboratorError.
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this CollaboratorError.
        Email field errors.

        :param email: The email of this CollaboratorError.
        :type: list[str]
        """

        self._email = email

    @property
    def first_name(self):
        """
        Gets the first_name of this CollaboratorError.
        First name field errors.

        :return: The first_name of this CollaboratorError.
        :rtype: list[str]
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this CollaboratorError.
        First name field errors.

        :param first_name: The first_name of this CollaboratorError.
        :type: list[str]
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this CollaboratorError.
        Last name field errors.

        :return: The last_name of this CollaboratorError.
        :rtype: list[str]
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this CollaboratorError.
        Last name field errors.

        :param last_name: The last_name of this CollaboratorError.
        :type: list[str]
        """

        self._last_name = last_name

    @property
    def member(self):
        """
        Gets the member of this CollaboratorError.
        Member field errors.

        :return: The member of this CollaboratorError.
        :rtype: list[str]
        """
        return self._member

    @member.setter
    def member(self, member):
        """
        Sets the member of this CollaboratorError.
        Member field errors.

        :param member: The member of this CollaboratorError.
        :type: list[str]
        """
        if member is None:
            raise ValueError("Invalid value for `member`, must not be `None`")

        self._member = member

    @property
    def permissions(self):
        """
        Gets the permissions of this CollaboratorError.
        Permissions field errors.

        :return: The permissions of this CollaboratorError.
        :rtype: list[str]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """
        Sets the permissions of this CollaboratorError.
        Permissions field errors.

        :param permissions: The permissions of this CollaboratorError.
        :type: list[str]
        """
        if permissions is None:
            raise ValueError("Invalid value for `permissions`, must not be `None`")

        self._permissions = permissions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CollaboratorError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class NotificationSettingsData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'emails_enabled': 'bool'
    }

    attribute_map = {
        'enabled': 'enabled',
        'emails_enabled': 'emails_enabled'
    }

    def __init__(self, enabled=None, emails_enabled=None):
        """
        NotificationSettingsData - a model defined in Swagger
        """

        self._enabled = None
        self._emails_enabled = None

        self.enabled = enabled
        self.emails_enabled = emails_enabled

    @property
    def enabled(self):
        """
        Gets the enabled of this NotificationSettingsData.
        Turn notifications on or off entirely.

        :return: The enabled of this NotificationSettingsData.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this NotificationSettingsData.
        Turn notifications on or off entirely.

        :param enabled: The enabled of this NotificationSettingsData.
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")

        self._enabled = enabled

    @property
    def emails_enabled(self):
        """
        Gets the emails_enabled of this NotificationSettingsData.
        Turn emails on or off.

        :return: The emails_enabled of this NotificationSettingsData.
        :rtype: bool
        """
        return self._emails_enabled

    @emails_enabled.setter
    def emails_enabled(self, emails_enabled):
        """
        Sets the emails_enabled of this NotificationSettingsData.
        Turn emails on or off.

        :param emails_enabled: The emails_enabled of this NotificationSettingsData.
        :type: bool
        """
        if emails_enabled is None:
            raise ValueError("Invalid value for `emails_enabled`, must not be `None`")

        self._emails_enabled = emails_enabled

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, NotificationSettingsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class CustomerData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'metadata': 'object',
        'account_balance': 'int',
        'currency': 'str',
        'last_invoice_sync': 'str',
        'user': 'str',
        'default_source': 'str'
    }

    attribute_map = {
        'metadata': 'metadata',
        'account_balance': 'account_balance',
        'currency': 'currency',
        'last_invoice_sync': 'last_invoice_sync',
        'user': 'user',
        'default_source': 'default_source'
    }

    def __init__(self, metadata=None, account_balance=None, currency=None, last_invoice_sync=None, user=None, default_source=None):
        """
        CustomerData - a model defined in Swagger
        """

        self._metadata = None
        self._account_balance = None
        self._currency = None
        self._last_invoice_sync = None
        self._user = None
        self._default_source = None

        if metadata is not None:
          self.metadata = metadata
        if account_balance is not None:
          self.account_balance = account_balance
        if currency is not None:
          self.currency = currency
        if last_invoice_sync is not None:
          self.last_invoice_sync = last_invoice_sync
        self.user = user
        if default_source is not None:
          self.default_source = default_source

    @property
    def metadata(self):
        """
        Gets the metadata of this CustomerData.
        Customer meta data.

        :return: The metadata of this CustomerData.
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this CustomerData.
        Customer meta data.

        :param metadata: The metadata of this CustomerData.
        :type: object
        """

        self._metadata = metadata

    @property
    def account_balance(self):
        """
        Gets the account_balance of this CustomerData.
        Account balance.

        :return: The account_balance of this CustomerData.
        :rtype: int
        """
        return self._account_balance

    @account_balance.setter
    def account_balance(self, account_balance):
        """
        Sets the account_balance of this CustomerData.
        Account balance.

        :param account_balance: The account_balance of this CustomerData.
        :type: int
        """

        self._account_balance = account_balance

    @property
    def currency(self):
        """
        Gets the currency of this CustomerData.
        Customer preferred currency.

        :return: The currency of this CustomerData.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this CustomerData.
        Customer preferred currency.

        :param currency: The currency of this CustomerData.
        :type: str
        """

        self._currency = currency

    @property
    def last_invoice_sync(self):
        """
        Gets the last_invoice_sync of this CustomerData.
        List date and time invoice was synced.

        :return: The last_invoice_sync of this CustomerData.
        :rtype: str
        """
        return self._last_invoice_sync

    @last_invoice_sync.setter
    def last_invoice_sync(self, last_invoice_sync):
        """
        Sets the last_invoice_sync of this CustomerData.
        List date and time invoice was synced.

        :param last_invoice_sync: The last_invoice_sync of this CustomerData.
        :type: str
        """

        self._last_invoice_sync = last_invoice_sync

    @property
    def user(self):
        """
        Gets the user of this CustomerData.
        User corresponding to customer.

        :return: The user of this CustomerData.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this CustomerData.
        User corresponding to customer.

        :param user: The user of this CustomerData.
        :type: str
        """
        if user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")

        self._user = user

    @property
    def default_source(self):
        """
        Gets the default_source of this CustomerData.
        Default source.

        :return: The default_source of this CustomerData.
        :rtype: str
        """
        return self._default_source

    @default_source.setter
    def default_source(self, default_source):
        """
        Sets the default_source of this CustomerData.
        Default source.

        :param default_source: The default_source of this CustomerData.
        :type: str
        """

        self._default_source = default_source

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomerData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerRunStatisticsData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start': 'str',
        'stop': 'str',
        'exit_code': 'int',
        'size': 'int',
        'stacktrace': 'str'
    }

    attribute_map = {
        'start': 'start',
        'stop': 'stop',
        'exit_code': 'exit_code',
        'size': 'size',
        'stacktrace': 'stacktrace'
    }

    def __init__(self, start=None, stop=None, exit_code=None, size=None, stacktrace=None):
        """
        ServerRunStatisticsData - a model defined in Swagger
        """

        self._start = None
        self._stop = None
        self._exit_code = None
        self._size = None
        self._stacktrace = None

        if start is not None:
          self.start = start
        if stop is not None:
          self.stop = stop
        if exit_code is not None:
          self.exit_code = exit_code
        if size is not None:
          self.size = size
        if stacktrace is not None:
          self.stacktrace = stacktrace

    @property
    def start(self):
        """
        Gets the start of this ServerRunStatisticsData.
        Server start.

        :return: The start of this ServerRunStatisticsData.
        :rtype: str
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this ServerRunStatisticsData.
        Server start.

        :param start: The start of this ServerRunStatisticsData.
        :type: str
        """

        self._start = start

    @property
    def stop(self):
        """
        Gets the stop of this ServerRunStatisticsData.
        Server stop.

        :return: The stop of this ServerRunStatisticsData.
        :rtype: str
        """
        return self._stop

    @stop.setter
    def stop(self, stop):
        """
        Sets the stop of this ServerRunStatisticsData.
        Server stop.

        :param stop: The stop of this ServerRunStatisticsData.
        :type: str
        """

        self._stop = stop

    @property
    def exit_code(self):
        """
        Gets the exit_code of this ServerRunStatisticsData.
        Server exit code.

        :return: The exit_code of this ServerRunStatisticsData.
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """
        Sets the exit_code of this ServerRunStatisticsData.
        Server exit code.

        :param exit_code: The exit_code of this ServerRunStatisticsData.
        :type: int
        """

        self._exit_code = exit_code

    @property
    def size(self):
        """
        Gets the size of this ServerRunStatisticsData.
        Server size.

        :return: The size of this ServerRunStatisticsData.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this ServerRunStatisticsData.
        Server size.

        :param size: The size of this ServerRunStatisticsData.
        :type: int
        """

        self._size = size

    @property
    def stacktrace(self):
        """
        Gets the stacktrace of this ServerRunStatisticsData.
        Server stacktrace.

        :return: The stacktrace of this ServerRunStatisticsData.
        :rtype: str
        """
        return self._stacktrace

    @stacktrace.setter
    def stacktrace(self, stacktrace):
        """
        Sets the stacktrace of this ServerRunStatisticsData.
        Server stacktrace.

        :param stacktrace: The stacktrace of this ServerRunStatisticsData.
        :type: str
        """

        self._stacktrace = stacktrace

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerRunStatisticsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Notification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'user': 'str',
        'actor': 'str',
        'target': 'str',
        'type': 'str',
        'timestamp': 'str',
        'read': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'user': 'user',
        'actor': 'actor',
        'target': 'target',
        'type': 'type',
        'timestamp': 'timestamp',
        'read': 'read'
    }

    def __init__(self, id=None, user=None, actor=None, target=None, type=None, timestamp=None, read=None):
        """
        Notification - a model defined in Swagger
        """

        self._id = None
        self._user = None
        self._actor = None
        self._target = None
        self._type = None
        self._timestamp = None
        self._read = None

        if id is not None:
          self.id = id
        if user is not None:
          self.user = user
        if actor is not None:
          self.actor = actor
        if target is not None:
          self.target = target
        if type is not None:
          self.type = type
        if timestamp is not None:
          self.timestamp = timestamp
        self.read = read

    @property
    def id(self):
        """
        Gets the id of this Notification.
        Notification unique identifier expressed as a UUID

        :return: The id of this Notification.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Notification.
        Notification unique identifier expressed as a UUID

        :param id: The id of this Notification.
        :type: str
        """

        self._id = id

    @property
    def user(self):
        """
        Gets the user of this Notification.
        User the notification is for.

        :return: The user of this Notification.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this Notification.
        User the notification is for.

        :param user: The user of this Notification.
        :type: str
        """

        self._user = user

    @property
    def actor(self):
        """
        Gets the actor of this Notification.
        Unique identifier of the object that triggered the notification.

        :return: The actor of this Notification.
        :rtype: str
        """
        return self._actor

    @actor.setter
    def actor(self, actor):
        """
        Sets the actor of this Notification.
        Unique identifier of the object that triggered the notification.

        :param actor: The actor of this Notification.
        :type: str
        """

        self._actor = actor

    @property
    def target(self):
        """
        Gets the target of this Notification.
        Unique identifier of the object that was acted upon by the object referred to in actor.

        :return: The target of this Notification.
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this Notification.
        Unique identifier of the object that was acted upon by the object referred to in actor.

        :param target: The target of this Notification.
        :type: str
        """

        self._target = target

    @property
    def type(self):
        """
        Gets the type of this Notification.
        Type of the notification, e.g. invoice.created, subscription.created, etc.

        :return: The type of this Notification.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Notification.
        Type of the notification, e.g. invoice.created, subscription.created, etc.

        :param type: The type of this Notification.
        :type: str
        """

        self._type = type

    @property
    def timestamp(self):
        """
        Gets the timestamp of this Notification.
        Timestamp that the notification was created at.

        :return: The timestamp of this Notification.
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this Notification.
        Timestamp that the notification was created at.

        :param timestamp: The timestamp of this Notification.
        :type: str
        """

        self._timestamp = timestamp

    @property
    def read(self):
        """
        Gets the read of this Notification.
        Whether or not the notification has been marked as read by the user.

        :return: The read of this Notification.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this Notification.
        Whether or not the notification has been marked as read by the user.

        :param read: The read of this Notification.
        :type: bool
        """
        if read is None:
            raise ValueError("Invalid value for `read`, must not be `None`")

        self._read = read

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Notification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class AuthApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def auth_jwt_token_auth(self, **kwargs):
        """
        Create JSON Web Token (JWT)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.auth_jwt_token_auth(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param JWTData jwt_data:
        :return: JWT
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.auth_jwt_token_auth_with_http_info(**kwargs)
        else:
            (data) = self.auth_jwt_token_auth_with_http_info(**kwargs)
            return data

    def auth_jwt_token_auth_with_http_info(self, **kwargs):
        """
        Create JSON Web Token (JWT)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.auth_jwt_token_auth_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param JWTData jwt_data:
        :return: JWT
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['jwt_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_jwt_token_auth" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'jwt_data' in params:
            body_params = params['jwt_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/auth/jwt-token-auth/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='JWT',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def auth_jwt_token_refresh(self, **kwargs):
        """
        Refresh a JSON Web Token (JWT)
        Obtains a new JSON Web Token using existing user credentials.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.auth_jwt_token_refresh(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RefreshJSONWebTokenData refreshjwt_data:
        :return: RefreshJSONWebToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.auth_jwt_token_refresh_with_http_info(**kwargs)
        else:
            (data) = self.auth_jwt_token_refresh_with_http_info(**kwargs)
            return data

    def auth_jwt_token_refresh_with_http_info(self, **kwargs):
        """
        Refresh a JSON Web Token (JWT)
        Obtains a new JSON Web Token using existing user credentials.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.auth_jwt_token_refresh_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RefreshJSONWebTokenData refreshjwt_data:
        :return: RefreshJSONWebToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['refreshjwt_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_jwt_token_refresh" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'refreshjwt_data' in params:
            body_params = params['refreshjwt_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/auth/jwt-token-refresh/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RefreshJSONWebToken',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def auth_jwt_token_verify(self, **kwargs):
        """
        Validate JSON Web Token (JWT)
        Checks veraciy of token.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.auth_jwt_token_verify(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VerifyJSONWebTokenData verifyjwt_data:
        :return: VerifyJSONWebToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.auth_jwt_token_verify_with_http_info(**kwargs)
        else:
            (data) = self.auth_jwt_token_verify_with_http_info(**kwargs)
            return data

    def auth_jwt_token_verify_with_http_info(self, **kwargs):
        """
        Validate JSON Web Token (JWT)
        Checks veraciy of token.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.auth_jwt_token_verify_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VerifyJSONWebTokenData verifyjwt_data:
        :return: VerifyJSONWebToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['verifyjwt_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_jwt_token_verify" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'verifyjwt_data' in params:
            body_params = params['verifyjwt_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/auth/jwt-token-verify/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='VerifyJSONWebToken',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def auth_register(self, **kwargs):
        """
        Register a user
        User registration requires confirming email address to activate user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.auth_register(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserData user_data:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.auth_register_with_http_info(**kwargs)
        else:
            (data) = self.auth_register_with_http_info(**kwargs)
            return data

    def auth_register_with_http_info(self, **kwargs):
        """
        Register a user
        User registration requires confirming email address to activate user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.auth_register_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserData user_data:
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth_register" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_data' in params:
            body_params = params['user_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/auth/register/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def oauth_login(self, provider, **kwargs):
        """
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.oauth_login(provider, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str provider: OAuth2 provider (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.oauth_login_with_http_info(provider, **kwargs)
        else:
            (data) = self.oauth_login_with_http_info(provider, **kwargs)
            return data

    def oauth_login_with_http_info(self, provider, **kwargs):
        """
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.oauth_login_with_http_info(provider, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str provider: OAuth2 provider (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['provider']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method oauth_login" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'provider' is set
        if ('provider' not in params) or (params['provider'] is None):
            raise ValueError("Missing the required parameter `provider` when calling `oauth_login`")


        collection_formats = {}

        path_params = {}
        if 'provider' in params:
            path_params['provider'] = params['provider']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/auth/login/{provider}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class BillingApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def billing_cards_create(self, namespace, **kwargs):
        """
        Create new credit card
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_create(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param CardDataPost card_data:
        :return: Card
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_cards_create_with_http_info(namespace, **kwargs)
        else:
            (data) = self.billing_cards_create_with_http_info(namespace, **kwargs)
            return data

    def billing_cards_create_with_http_info(self, namespace, **kwargs):
        """
        Create new credit card
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_create_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param CardDataPost card_data:
        :return: Card
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'card_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_cards_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_cards_create`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'card_data' in params:
            body_params = params['card_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/cards/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Card',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_cards_delete(self, namespace, id, **kwargs):
        """
        Delete a credit card
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_delete(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Card unique identifier expressed as UUID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_cards_delete_with_http_info(namespace, id, **kwargs)
        else:
            (data) = self.billing_cards_delete_with_http_info(namespace, id, **kwargs)
            return data

    def billing_cards_delete_with_http_info(self, namespace, id, **kwargs):
        """
        Delete a credit card
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_delete_with_http_info(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Card unique identifier expressed as UUID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_cards_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_cards_delete`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_cards_delete`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/cards/{id}/', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_cards_list(self, namespace, **kwargs):
        """
        Get credit cards
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_list(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str limit: Set limit when retrieving credit or debit cards.
        :param str offset: Set offset when retriving cards.
        :param str ordering: Order when retrieving cards.
        :return: list[Card]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_cards_list_with_http_info(namespace, **kwargs)
        else:
            (data) = self.billing_cards_list_with_http_info(namespace, **kwargs)
            return data

    def billing_cards_list_with_http_info(self, namespace, **kwargs):
        """
        Get credit cards
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_list_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str limit: Set limit when retrieving credit or debit cards.
        :param str offset: Set offset when retriving cards.
        :param str ordering: Order when retrieving cards.
        :return: list[Card]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'limit', 'offset', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_cards_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_cards_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/cards/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Card]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_cards_read(self, namespace, id, **kwargs):
        """
        Get credit card by id
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_read(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: User unique identifier expressed as UUID. (required)
        :return: Card
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_cards_read_with_http_info(namespace, id, **kwargs)
        else:
            (data) = self.billing_cards_read_with_http_info(namespace, id, **kwargs)
            return data

    def billing_cards_read_with_http_info(self, namespace, id, **kwargs):
        """
        Get credit card by id
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_read_with_http_info(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: User unique identifier expressed as UUID. (required)
        :return: Card
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_cards_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_cards_read`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_cards_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/cards/{id}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Card',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_cards_replace(self, namespace, id, **kwargs):
        """
        Replace a credit card
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_replace(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id:  (required)
        :param CardDataPutandPatch card_data:
        :return: Card
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_cards_replace_with_http_info(namespace, id, **kwargs)
        else:
            (data) = self.billing_cards_replace_with_http_info(namespace, id, **kwargs)
            return data

    def billing_cards_replace_with_http_info(self, namespace, id, **kwargs):
        """
        Replace a credit card
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_replace_with_http_info(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id:  (required)
        :param CardDataPutandPatch card_data:
        :return: Card
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'id', 'card_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_cards_replace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_cards_replace`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_cards_replace`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'card_data' in params:
            body_params = params['card_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/cards/{id}/', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Card',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_cards_update(self, namespace, id, **kwargs):
        """
        Update a credit card
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_update(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Card unique identifier. (required)
        :param CardDataPutandPatch card_data:
        :return: Card
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_cards_update_with_http_info(namespace, id, **kwargs)
        else:
            (data) = self.billing_cards_update_with_http_info(namespace, id, **kwargs)
            return data

    def billing_cards_update_with_http_info(self, namespace, id, **kwargs):
        """
        Update a credit card
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_cards_update_with_http_info(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Card unique identifier. (required)
        :param CardDataPutandPatch card_data:
        :return: Card
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'id', 'card_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_cards_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_cards_update`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_cards_update`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'card_data' in params:
            body_params = params['card_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/cards/{id}/', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Card',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_invoice_items_list(self, namespace, invoice_id, **kwargs):
        """
        Get invoice items for a given invoice.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_invoice_items_list(namespace, invoice_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str invoice_id: Invoice id, expressed as UUID. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[InvoiceItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_invoice_items_list_with_http_info(namespace, invoice_id, **kwargs)
        else:
            (data) = self.billing_invoice_items_list_with_http_info(namespace, invoice_id, **kwargs)
            return data

    def billing_invoice_items_list_with_http_info(self, namespace, invoice_id, **kwargs):
        """
        Get invoice items for a given invoice.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_invoice_items_list_with_http_info(namespace, invoice_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str invoice_id: Invoice id, expressed as UUID. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[InvoiceItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'invoice_id', 'limit', 'offset', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_invoice_items_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_invoice_items_list`")
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params) or (params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `billing_invoice_items_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'invoice_id' in params:
            path_params['invoice_id'] = params['invoice_id']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/invoices/{invoice_id}/invoice-items/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[InvoiceItem]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_invoice_items_read(self, namespace, invoice_id, id, **kwargs):
        """
        Get a specific InvoiceItem.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_invoice_items_read(namespace, invoice_id, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str invoice_id: Invoice id, expressed as UUID. (required)
        :param str id: InvoiceItem id, expressed as UUID. (required)
        :return: InvoiceItem
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_invoice_items_read_with_http_info(namespace, invoice_id, id, **kwargs)
        else:
            (data) = self.billing_invoice_items_read_with_http_info(namespace, invoice_id, id, **kwargs)
            return data

    def billing_invoice_items_read_with_http_info(self, namespace, invoice_id, id, **kwargs):
        """
        Get a specific InvoiceItem.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_invoice_items_read_with_http_info(namespace, invoice_id, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str invoice_id: Invoice id, expressed as UUID. (required)
        :param str id: InvoiceItem id, expressed as UUID. (required)
        :return: InvoiceItem
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'invoice_id', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_invoice_items_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_invoice_items_read`")
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params) or (params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `billing_invoice_items_read`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_invoice_items_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'invoice_id' in params:
            path_params['invoice_id'] = params['invoice_id']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/invoices/{invoice_id}/invoice-items/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='InvoiceItem',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_invoices_list(self, namespace, **kwargs):
        """
        Get invoices
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_invoices_list(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[Invoice]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_invoices_list_with_http_info(namespace, **kwargs)
        else:
            (data) = self.billing_invoices_list_with_http_info(namespace, **kwargs)
            return data

    def billing_invoices_list_with_http_info(self, namespace, **kwargs):
        """
        Get invoices
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_invoices_list_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[Invoice]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'limit', 'offset', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_invoices_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_invoices_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/invoices/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Invoice]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_invoices_read(self, namespace, id, **kwargs):
        """
        Get an invoice
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_invoices_read(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Invoice unique identifier expressed as UUID. (required)
        :return: Invoice
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_invoices_read_with_http_info(namespace, id, **kwargs)
        else:
            (data) = self.billing_invoices_read_with_http_info(namespace, id, **kwargs)
            return data

    def billing_invoices_read_with_http_info(self, namespace, id, **kwargs):
        """
        Get an invoice
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_invoices_read_with_http_info(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Invoice unique identifier expressed as UUID. (required)
        :return: Invoice
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_invoices_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_invoices_read`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_invoices_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/invoices/{id}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Invoice',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_plans_list(self, namespace, **kwargs):
        """
        Get billing plans
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_plans_list(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[Plan]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_plans_list_with_http_info(namespace, **kwargs)
        else:
            (data) = self.billing_plans_list_with_http_info(namespace, **kwargs)
            return data

    def billing_plans_list_with_http_info(self, namespace, **kwargs):
        """
        Get billing plans
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_plans_list_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[Plan]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'limit', 'offset', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_plans_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_plans_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/plans/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Plan]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_plans_read(self, namespace, id, **kwargs):
        """
        Get a billing plan
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_plans_read(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Plan unique identifier expressed as UUID. (required)
        :return: Plan
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_plans_read_with_http_info(namespace, id, **kwargs)
        else:
            (data) = self.billing_plans_read_with_http_info(namespace, id, **kwargs)
            return data

    def billing_plans_read_with_http_info(self, namespace, id, **kwargs):
        """
        Get a billing plan
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_plans_read_with_http_info(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Plan unique identifier expressed as UUID. (required)
        :return: Plan
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_plans_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_plans_read`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_plans_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/plans/{id}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Plan',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_subscriptions_create(self, namespace, **kwargs):
        """
        Create a new subscription
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_subscriptions_create(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param SubscriptionData subscription_data:
        :return: Subscription
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_subscriptions_create_with_http_info(namespace, **kwargs)
        else:
            (data) = self.billing_subscriptions_create_with_http_info(namespace, **kwargs)
            return data

    def billing_subscriptions_create_with_http_info(self, namespace, **kwargs):
        """
        Create a new subscription
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_subscriptions_create_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param SubscriptionData subscription_data:
        :return: Subscription
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'subscription_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_subscriptions_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_subscriptions_create`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'subscription_data' in params:
            body_params = params['subscription_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/subscriptions/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Subscription',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_subscriptions_delete(self, namespace, id, **kwargs):
        """
        Delete a subscription
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_subscriptions_delete(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Subscription unique identifier expressed as UUID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_subscriptions_delete_with_http_info(namespace, id, **kwargs)
        else:
            (data) = self.billing_subscriptions_delete_with_http_info(namespace, id, **kwargs)
            return data

    def billing_subscriptions_delete_with_http_info(self, namespace, id, **kwargs):
        """
        Delete a subscription
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_subscriptions_delete_with_http_info(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Subscription unique identifier expressed as UUID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_subscriptions_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_subscriptions_delete`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_subscriptions_delete`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/subscriptions/{id}/', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_subscriptions_list(self, namespace, **kwargs):
        """
        Get active subscriptons
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_subscriptions_list(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[Subscription]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_subscriptions_list_with_http_info(namespace, **kwargs)
        else:
            (data) = self.billing_subscriptions_list_with_http_info(namespace, **kwargs)
            return data

    def billing_subscriptions_list_with_http_info(self, namespace, **kwargs):
        """
        Get active subscriptons
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_subscriptions_list_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str limit: Limit when getting items.
        :param str offset: Offset when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[Subscription]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'limit', 'offset', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_subscriptions_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_subscriptions_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/subscriptions/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Subscription]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def billing_subscriptions_read(self, namespace, id, **kwargs):
        """
        Get a subscriptions
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_subscriptions_read(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Unique identifier expressed as UUID. (required)
        :return: Subscription
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.billing_subscriptions_read_with_http_info(namespace, id, **kwargs)
        else:
            (data) = self.billing_subscriptions_read_with_http_info(namespace, id, **kwargs)
            return data

    def billing_subscriptions_read_with_http_info(self, namespace, id, **kwargs):
        """
        Get a subscriptions
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.billing_subscriptions_read_with_http_info(namespace, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str id: Unique identifier expressed as UUID. (required)
        :return: Subscription
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_subscriptions_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `billing_subscriptions_read`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `billing_subscriptions_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/billing/subscriptions/{id}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Subscription',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerSizeError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'id': 'list[str]',
        'name': 'list[str]',
        'cpu': 'list[str]',
        'memory': 'list[str]',
        'active': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'id': 'id',
        'name': 'name',
        'cpu': 'cpu',
        'memory': 'memory',
        'active': 'active'
    }

    def __init__(self, non_field_errors=None, id=None, name=None, cpu=None, memory=None, active=None):
        """
        ServerSizeError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._id = None
        self._name = None
        self._cpu = None
        self._memory = None
        self._active = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if cpu is not None:
          self.cpu = cpu
        if memory is not None:
          self.memory = memory
        if active is not None:
          self.active = active

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this ServerSizeError.
        Errors not connected to any field.

        :return: The non_field_errors of this ServerSizeError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this ServerSizeError.
        Errors not connected to any field.

        :param non_field_errors: The non_field_errors of this ServerSizeError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def id(self):
        """
        Gets the id of this ServerSizeError.
        Id field errors.

        :return: The id of this ServerSizeError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServerSizeError.
        Id field errors.

        :param id: The id of this ServerSizeError.
        :type: list[str]
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ServerSizeError.
        Name field errors.

        :return: The name of this ServerSizeError.
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServerSizeError.
        Name field errors.

        :param name: The name of this ServerSizeError.
        :type: list[str]
        """

        self._name = name

    @property
    def cpu(self):
        """
        Gets the cpu of this ServerSizeError.
        CPU field errors.

        :return: The cpu of this ServerSizeError.
        :rtype: list[str]
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu):
        """
        Sets the cpu of this ServerSizeError.
        CPU field errors.

        :param cpu: The cpu of this ServerSizeError.
        :type: list[str]
        """

        self._cpu = cpu

    @property
    def memory(self):
        """
        Gets the memory of this ServerSizeError.
        Memory field errors.

        :return: The memory of this ServerSizeError.
        :rtype: list[str]
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """
        Sets the memory of this ServerSizeError.
        Memory field errors.

        :param memory: The memory of this ServerSizeError.
        :type: list[str]
        """

        self._memory = memory

    @property
    def active(self):
        """
        Gets the active of this ServerSizeError.
        Active field errors.

        :return: The active of this ServerSizeError.
        :rtype: list[str]
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this ServerSizeError.
        Active field errors.

        :param active: The active of this ServerSizeError.
        :type: list[str]
        """

        self._active = active

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerSizeError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class CardDataPutandPatch(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'address_line1': 'str',
        'address_line2': 'str',
        'address_city': 'str',
        'address_state': 'str',
        'address_zip': 'str',
        'address_country': 'str',
        'exp_month': 'int',
        'exp_year': 'int'
    }

    attribute_map = {
        'name': 'name',
        'address_line1': 'address_line1',
        'address_line2': 'address_line2',
        'address_city': 'address_city',
        'address_state': 'address_state',
        'address_zip': 'address_zip',
        'address_country': 'address_country',
        'exp_month': 'exp_month',
        'exp_year': 'exp_year'
    }

    def __init__(self, name=None, address_line1=None, address_line2=None, address_city=None, address_state=None, address_zip=None, address_country=None, exp_month=None, exp_year=None):
        """
        CardDataPutandPatch - a model defined in Swagger
        """

        self._name = None
        self._address_line1 = None
        self._address_line2 = None
        self._address_city = None
        self._address_state = None
        self._address_zip = None
        self._address_country = None
        self._exp_month = None
        self._exp_year = None

        if name is not None:
          self.name = name
        if address_line1 is not None:
          self.address_line1 = address_line1
        if address_line2 is not None:
          self.address_line2 = address_line2
        if address_city is not None:
          self.address_city = address_city
        if address_state is not None:
          self.address_state = address_state
        if address_zip is not None:
          self.address_zip = address_zip
        if address_country is not None:
          self.address_country = address_country
        if exp_month is not None:
          self.exp_month = exp_month
        if exp_year is not None:
          self.exp_year = exp_year

    @property
    def name(self):
        """
        Gets the name of this CardDataPutandPatch.
        Card name.

        :return: The name of this CardDataPutandPatch.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CardDataPutandPatch.
        Card name.

        :param name: The name of this CardDataPutandPatch.
        :type: str
        """

        self._name = name

    @property
    def address_line1(self):
        """
        Gets the address_line1 of this CardDataPutandPatch.
        Address line 1.

        :return: The address_line1 of this CardDataPutandPatch.
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """
        Sets the address_line1 of this CardDataPutandPatch.
        Address line 1.

        :param address_line1: The address_line1 of this CardDataPutandPatch.
        :type: str
        """

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """
        Gets the address_line2 of this CardDataPutandPatch.
        Address line 2.

        :return: The address_line2 of this CardDataPutandPatch.
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """
        Sets the address_line2 of this CardDataPutandPatch.
        Address line 2.

        :param address_line2: The address_line2 of this CardDataPutandPatch.
        :type: str
        """

        self._address_line2 = address_line2

    @property
    def address_city(self):
        """
        Gets the address_city of this CardDataPutandPatch.
        Address city.

        :return: The address_city of this CardDataPutandPatch.
        :rtype: str
        """
        return self._address_city

    @address_city.setter
    def address_city(self, address_city):
        """
        Sets the address_city of this CardDataPutandPatch.
        Address city.

        :param address_city: The address_city of this CardDataPutandPatch.
        :type: str
        """

        self._address_city = address_city

    @property
    def address_state(self):
        """
        Gets the address_state of this CardDataPutandPatch.
        Address state.

        :return: The address_state of this CardDataPutandPatch.
        :rtype: str
        """
        return self._address_state

    @address_state.setter
    def address_state(self, address_state):
        """
        Sets the address_state of this CardDataPutandPatch.
        Address state.

        :param address_state: The address_state of this CardDataPutandPatch.
        :type: str
        """

        self._address_state = address_state

    @property
    def address_zip(self):
        """
        Gets the address_zip of this CardDataPutandPatch.
        Address zip code.

        :return: The address_zip of this CardDataPutandPatch.
        :rtype: str
        """
        return self._address_zip

    @address_zip.setter
    def address_zip(self, address_zip):
        """
        Sets the address_zip of this CardDataPutandPatch.
        Address zip code.

        :param address_zip: The address_zip of this CardDataPutandPatch.
        :type: str
        """

        self._address_zip = address_zip

    @property
    def address_country(self):
        """
        Gets the address_country of this CardDataPutandPatch.
        Address country.

        :return: The address_country of this CardDataPutandPatch.
        :rtype: str
        """
        return self._address_country

    @address_country.setter
    def address_country(self, address_country):
        """
        Sets the address_country of this CardDataPutandPatch.
        Address country.

        :param address_country: The address_country of this CardDataPutandPatch.
        :type: str
        """

        self._address_country = address_country

    @property
    def exp_month(self):
        """
        Gets the exp_month of this CardDataPutandPatch.
        Card expiration month.

        :return: The exp_month of this CardDataPutandPatch.
        :rtype: int
        """
        return self._exp_month

    @exp_month.setter
    def exp_month(self, exp_month):
        """
        Sets the exp_month of this CardDataPutandPatch.
        Card expiration month.

        :param exp_month: The exp_month of this CardDataPutandPatch.
        :type: int
        """

        self._exp_month = exp_month

    @property
    def exp_year(self):
        """
        Gets the exp_year of this CardDataPutandPatch.
        Card expiration year.

        :return: The exp_year of this CardDataPutandPatch.
        :rtype: int
        """
        return self._exp_year

    @exp_year.setter
    def exp_year(self, exp_year):
        """
        Sets the exp_year of this CardDataPutandPatch.
        Card expiration year.

        :param exp_year: The exp_year of this CardDataPutandPatch.
        :type: int
        """

        self._exp_year = exp_year

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CardDataPutandPatch):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Action(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'resource_uri': 'str',
        'payload': 'object',
        'action': 'str',
        'method': 'str',
        'user': 'str',
        'user_agent': 'str',
        'start_date': 'str',
        'end_date': 'str',
        'state': 'str',
        'ip': 'str',
        'object': 'str',
        'is_user_action': 'bool',
        'can_be_cancelled': 'bool',
        'can_be_retried': 'bool',
        'path': 'str',
        'action_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'resource_uri': 'resource_uri',
        'payload': 'payload',
        'action': 'action',
        'method': 'method',
        'user': 'user',
        'user_agent': 'user_agent',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'state': 'state',
        'ip': 'ip',
        'object': 'object',
        'is_user_action': 'is_user_action',
        'can_be_cancelled': 'can_be_cancelled',
        'can_be_retried': 'can_be_retried',
        'path': 'path',
        'action_name': 'action_name'
    }

    def __init__(self, id=None, resource_uri=None, payload=None, action=None, method=None, user=None, user_agent=None, start_date=None, end_date=None, state=None, ip=None, object=None, is_user_action=None, can_be_cancelled=None, can_be_retried=None, path=None, action_name=None):
        """
        Action - a model defined in Swagger
        """

        self._id = None
        self._resource_uri = None
        self._payload = None
        self._action = None
        self._method = None
        self._user = None
        self._user_agent = None
        self._start_date = None
        self._end_date = None
        self._state = None
        self._ip = None
        self._object = None
        self._is_user_action = None
        self._can_be_cancelled = None
        self._can_be_retried = None
        self._path = None
        self._action_name = None

        if id is not None:
          self.id = id
        if resource_uri is not None:
          self.resource_uri = resource_uri
        if payload is not None:
          self.payload = payload
        self.action = action
        self.method = method
        if user is not None:
          self.user = user
        self.user_agent = user_agent
        if start_date is not None:
          self.start_date = start_date
        if end_date is not None:
          self.end_date = end_date
        self.state = state
        if ip is not None:
          self.ip = ip
        if object is not None:
          self.object = object
        if is_user_action is not None:
          self.is_user_action = is_user_action
        if can_be_cancelled is not None:
          self.can_be_cancelled = can_be_cancelled
        if can_be_retried is not None:
          self.can_be_retried = can_be_retried
        if path is not None:
          self.path = path
        if action_name is not None:
          self.action_name = action_name

    @property
    def id(self):
        """
        Gets the id of this Action.
        Action unique identifier, expressed as UUID.

        :return: The id of this Action.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Action.
        Action unique identifier, expressed as UUID.

        :param id: The id of this Action.
        :type: str
        """

        self._id = id

    @property
    def resource_uri(self):
        """
        Gets the resource_uri of this Action.
        Resource URI.

        :return: The resource_uri of this Action.
        :rtype: str
        """
        return self._resource_uri

    @resource_uri.setter
    def resource_uri(self, resource_uri):
        """
        Sets the resource_uri of this Action.
        Resource URI.

        :param resource_uri: The resource_uri of this Action.
        :type: str
        """

        self._resource_uri = resource_uri

    @property
    def payload(self):
        """
        Gets the payload of this Action.
        Object action payload.

        :return: The payload of this Action.
        :rtype: object
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """
        Sets the payload of this Action.
        Object action payload.

        :param payload: The payload of this Action.
        :type: object
        """

        self._payload = payload

    @property
    def action(self):
        """
        Gets the action of this Action.
        Action name.

        :return: The action of this Action.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this Action.
        Action name.

        :param action: The action of this Action.
        :type: str
        """
        if action is None:
            raise ValueError("Invalid value for `action`, must not be `None`")

        self._action = action

    @property
    def method(self):
        """
        Gets the method of this Action.
        Action method.

        :return: The method of this Action.
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """
        Sets the method of this Action.
        Action method.

        :param method: The method of this Action.
        :type: str
        """
        if method is None:
            raise ValueError("Invalid value for `method`, must not be `None`")

        self._method = method

    @property
    def user(self):
        """
        Gets the user of this Action.
        User that action is assigned to.

        :return: The user of this Action.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this Action.
        User that action is assigned to.

        :param user: The user of this Action.
        :type: str
        """

        self._user = user

    @property
    def user_agent(self):
        """
        Gets the user_agent of this Action.
        User agent that action is related to.

        :return: The user_agent of this Action.
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """
        Sets the user_agent of this Action.
        User agent that action is related to.

        :param user_agent: The user_agent of this Action.
        :type: str
        """
        if user_agent is None:
            raise ValueError("Invalid value for `user_agent`, must not be `None`")

        self._user_agent = user_agent

    @property
    def start_date(self):
        """
        Gets the start_date of this Action.
        Action date and time start.

        :return: The start_date of this Action.
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this Action.
        Action date and time start.

        :param start_date: The start_date of this Action.
        :type: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this Action.
        Action needs to end before a certain date and time.

        :return: The end_date of this Action.
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this Action.
        Action needs to end before a certain date and time.

        :param end_date: The end_date of this Action.
        :type: str
        """

        self._end_date = end_date

    @property
    def state(self):
        """
        Gets the state of this Action.
        Action state.

        :return: The state of this Action.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Action.
        Action state.

        :param state: The state of this Action.
        :type: str
        """
        if state is None:
            raise ValueError("Invalid value for `state`, must not be `None`")

        self._state = state

    @property
    def ip(self):
        """
        Gets the ip of this Action.
        IP address that action is related to.

        :return: The ip of this Action.
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """
        Sets the ip of this Action.
        IP address that action is related to.

        :param ip: The ip of this Action.
        :type: str
        """

        self._ip = ip

    @property
    def object(self):
        """
        Gets the object of this Action.
        Action object.

        :return: The object of this Action.
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """
        Sets the object of this Action.
        Action object.

        :param object: The object of this Action.
        :type: str
        """

        self._object = object

    @property
    def is_user_action(self):
        """
        Gets the is_user_action of this Action.
        Is the action related to a user, or not.

        :return: The is_user_action of this Action.
        :rtype: bool
        """
        return self._is_user_action

    @is_user_action.setter
    def is_user_action(self, is_user_action):
        """
        Sets the is_user_action of this Action.
        Is the action related to a user, or not.

        :param is_user_action: The is_user_action of this Action.
        :type: bool
        """

        self._is_user_action = is_user_action

    @property
    def can_be_cancelled(self):
        """
        Gets the can_be_cancelled of this Action.
        Can action be cancelled, or not.

        :return: The can_be_cancelled of this Action.
        :rtype: bool
        """
        return self._can_be_cancelled

    @can_be_cancelled.setter
    def can_be_cancelled(self, can_be_cancelled):
        """
        Sets the can_be_cancelled of this Action.
        Can action be cancelled, or not.

        :param can_be_cancelled: The can_be_cancelled of this Action.
        :type: bool
        """

        self._can_be_cancelled = can_be_cancelled

    @property
    def can_be_retried(self):
        """
        Gets the can_be_retried of this Action.
        May action be retried, or not.

        :return: The can_be_retried of this Action.
        :rtype: bool
        """
        return self._can_be_retried

    @can_be_retried.setter
    def can_be_retried(self, can_be_retried):
        """
        Sets the can_be_retried of this Action.
        May action be retried, or not.

        :param can_be_retried: The can_be_retried of this Action.
        :type: bool
        """

        self._can_be_retried = can_be_retried

    @property
    def path(self):
        """
        Gets the path of this Action.
        Action path.

        :return: The path of this Action.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this Action.
        Action path.

        :param path: The path of this Action.
        :type: str
        """

        self._path = path

    @property
    def action_name(self):
        """
        Gets the action_name of this Action.
        Action name.

        :return: The action_name of this Action.
        :rtype: str
        """
        return self._action_name

    @action_name.setter
    def action_name(self, action_name):
        """
        Sets the action_name of this Action.
        Action name.

        :param action_name: The action_name of this Action.
        :type: str
        """

        self._action_name = action_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Action):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class InvoiceItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'stripe_id': 'str',
        'created': 'str',
        'metadata': 'object',
        'livemode': 'bool',
        'invoice': 'str',
        'amount': 'int',
        'currency': 'str',
        'invoice_date': 'str',
        'proration': 'bool',
        'quantity': 'int',
        'description': 'str'
    }

    attribute_map = {
        'id': 'id',
        'stripe_id': 'stripe_id',
        'created': 'created',
        'metadata': 'metadata',
        'livemode': 'livemode',
        'invoice': 'invoice',
        'amount': 'amount',
        'currency': 'currency',
        'invoice_date': 'invoice_date',
        'proration': 'proration',
        'quantity': 'quantity',
        'description': 'description'
    }

    def __init__(self, id=None, stripe_id=None, created=None, metadata=None, livemode=None, invoice=None, amount=None, currency=None, invoice_date=None, proration=None, quantity=None, description=None):
        """
        InvoiceItem - a model defined in Swagger
        """

        self._id = None
        self._stripe_id = None
        self._created = None
        self._metadata = None
        self._livemode = None
        self._invoice = None
        self._amount = None
        self._currency = None
        self._invoice_date = None
        self._proration = None
        self._quantity = None
        self._description = None

        if id is not None:
          self.id = id
        self.stripe_id = stripe_id
        self.created = created
        if metadata is not None:
          self.metadata = metadata
        if livemode is not None:
          self.livemode = livemode
        self.invoice = invoice
        self.amount = amount
        self.currency = currency
        self.invoice_date = invoice_date
        if proration is not None:
          self.proration = proration
        self.quantity = quantity
        if description is not None:
          self.description = description

    @property
    def id(self):
        """
        Gets the id of this InvoiceItem.
        InvoiceItem unique identifier expressed as UUID.

        :return: The id of this InvoiceItem.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this InvoiceItem.
        InvoiceItem unique identifier expressed as UUID.

        :param id: The id of this InvoiceItem.
        :type: str
        """

        self._id = id

    @property
    def stripe_id(self):
        """
        Gets the stripe_id of this InvoiceItem.
        Stripe account identifier.

        :return: The stripe_id of this InvoiceItem.
        :rtype: str
        """
        return self._stripe_id

    @stripe_id.setter
    def stripe_id(self, stripe_id):
        """
        Sets the stripe_id of this InvoiceItem.
        Stripe account identifier.

        :param stripe_id: The stripe_id of this InvoiceItem.
        :type: str
        """
        if stripe_id is None:
            raise ValueError("Invalid value for `stripe_id`, must not be `None`")

        self._stripe_id = stripe_id

    @property
    def created(self):
        """
        Gets the created of this InvoiceItem.
        Date and time when invoice was created.

        :return: The created of this InvoiceItem.
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """
        Sets the created of this InvoiceItem.
        Date and time when invoice was created.

        :param created: The created of this InvoiceItem.
        :type: str
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")

        self._created = created

    @property
    def metadata(self):
        """
        Gets the metadata of this InvoiceItem.
        Optional metadata object of invoice.

        :return: The metadata of this InvoiceItem.
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this InvoiceItem.
        Optional metadata object of invoice.

        :param metadata: The metadata of this InvoiceItem.
        :type: object
        """

        self._metadata = metadata

    @property
    def livemode(self):
        """
        Gets the livemode of this InvoiceItem.
        Boolean that determines whether invoice is live, or not.

        :return: The livemode of this InvoiceItem.
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """
        Sets the livemode of this InvoiceItem.
        Boolean that determines whether invoice is live, or not.

        :param livemode: The livemode of this InvoiceItem.
        :type: bool
        """

        self._livemode = livemode

    @property
    def invoice(self):
        """
        Gets the invoice of this InvoiceItem.
        Invoice unique identifier expressed as UUID.

        :return: The invoice of this InvoiceItem.
        :rtype: str
        """
        return self._invoice

    @invoice.setter
    def invoice(self, invoice):
        """
        Sets the invoice of this InvoiceItem.
        Invoice unique identifier expressed as UUID.

        :param invoice: The invoice of this InvoiceItem.
        :type: str
        """
        if invoice is None:
            raise ValueError("Invalid value for `invoice`, must not be `None`")

        self._invoice = invoice

    @property
    def amount(self):
        """
        Gets the amount of this InvoiceItem.
        Amount the the invoice item will be billed for.

        :return: The amount of this InvoiceItem.
        :rtype: int
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this InvoiceItem.
        Amount the the invoice item will be billed for.

        :param amount: The amount of this InvoiceItem.
        :type: int
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")

        self._amount = amount

    @property
    def currency(self):
        """
        Gets the currency of this InvoiceItem.
        Currency used in invoice.

        :return: The currency of this InvoiceItem.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this InvoiceItem.
        Currency used in invoice.

        :param currency: The currency of this InvoiceItem.
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")

        self._currency = currency

    @property
    def invoice_date(self):
        """
        Gets the invoice_date of this InvoiceItem.
        Date the item was added to the invoice.

        :return: The invoice_date of this InvoiceItem.
        :rtype: str
        """
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, invoice_date):
        """
        Sets the invoice_date of this InvoiceItem.
        Date the item was added to the invoice.

        :param invoice_date: The invoice_date of this InvoiceItem.
        :type: str
        """
        if invoice_date is None:
            raise ValueError("Invalid value for `invoice_date`, must not be `None`")

        self._invoice_date = invoice_date

    @property
    def proration(self):
        """
        Gets the proration of this InvoiceItem.
        Whether or not the items cost will be prorated for the billing period.

        :return: The proration of this InvoiceItem.
        :rtype: bool
        """
        return self._proration

    @proration.setter
    def proration(self, proration):
        """
        Sets the proration of this InvoiceItem.
        Whether or not the items cost will be prorated for the billing period.

        :param proration: The proration of this InvoiceItem.
        :type: bool
        """

        self._proration = proration

    @property
    def quantity(self):
        """
        Gets the quantity of this InvoiceItem.
        Number of units for this item.

        :return: The quantity of this InvoiceItem.
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this InvoiceItem.
        Number of units for this item.

        :param quantity: The quantity of this InvoiceItem.
        :type: int
        """
        if quantity is None:
            raise ValueError("Invalid value for `quantity`, must not be `None`")

        self._quantity = quantity

    @property
    def description(self):
        """
        Gets the description of this InvoiceItem.
        Item description.

        :return: The description of this InvoiceItem.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this InvoiceItem.
        Item description.

        :param description: The description of this InvoiceItem.
        :type: str
        """

        self._description = description

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InvoiceItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
